@@ -11,7 +11,7 @@ Usage::
 """
 import sys
 from datetime import datetime
-from typing import Any, Dict, List
+from typing import IO, Any, Dict, List, Union
 
 if sys.version_info >= (3, 8):
     from typing import Literal
@@ -1097,7 +1097,7 @@ MaintenanceWindowIdentityTypeDef = TypedDict(
 
 MaintenanceWindowLambdaParametersTypeDef = TypedDict(
     "MaintenanceWindowLambdaParametersTypeDef",
-    {"ClientContext": str, "Qualifier": str, "Payload": bytes},
+    {"ClientContext": str, "Qualifier": str, "Payload": Union[bytes, IO[bytes]]},
     total=False,
 )
 
